class oracle::install (
  # Oracle社からDownloadしたzipファイルの名称
  $oracle_client_archive_name = 'linux.x64_11gR2_client.zip',
  # アーカイブの一時展開領域
  $oracle_client_tmp_dir      = '/var/tmp/staging',
){
  # 必須パッケージのリスト
  $install = [ 'binutils.x86_64', 'compat-libstdc++-33.x86_64', 'glibc.x86_64','ksh.x86_64','libaio.x86_64','libgcc.x86_64', 'libstdc++.x86_64', 'make.x86_64','compat-libcap1.x86_64', 'gcc.x86_64','gcc-c++.x86_64','glibc-devel.x86_64','libaio-devel.x86_64','libstdc++-devel.x86_64','sysstat.x86_64','unixODBC-devel','glibc.i686','libXext.x86_64','libXtst.x86_64','unzip']

  # 手順1. 必須パッケージのインストール
  package { $install:
    ensure  => present,
  }

  # 手順2. oinstall、dba、operグループの作成とoracleユーザの作成
  $all_groups = ['oinstall','dba' ,'oper']
    group { $all_groups :
    ensure      => present,
    require     => Package[$install],
  }
  user { 'oracle' :
    ensure      => present,
    uid         => 500,
    gid         => 'oinstall',
    groups      => ['oinstall','dba','oper'],
    shell       => '/bin/bash',
    password    => '$1$AaIc802i$b.iV28BvWqJ8PJ8KArQfc0',
    home        => "/home/oracle",
    comment     => "This user oracle was created by Puppet",
    require     => Group[$all_groups],
    managehome  => true,
  }

  # 手順3. Oracle Universal Installerで本体のインストール
  file { '/u01':
    ensure  => directory,
    owner   => 'oracle',
    group   => 'oinstall',
    mode    => '0755',
    require => User['oracle'],
  }
  file { '/u01/app':
    ensure  => directory,
    owner   => 'oracle',
    group   => 'oinstall',
    mode    => '0755',
    require => User['oracle'],
  }
  file { '/u01/app/oracle':
    ensure  => directory,
    owner   => 'oracle',
    group   => 'oinstall',
    mode    => '0755',
    require => User['oracle'],
  }
  class {'staging':
    path  => $oracle_client_tmp_dir,
    owner => 'root',
    group => 'root',
  }
  staging::file { $oracle_client_archive_name:
    source  => "puppet:///modules/oracle/${oracle_client_archive_name}",
    require => User['oracle'],
  }
  staging::extract { $oracle_client_archive_name:
    target  => '/home/oracle',
    creates => '/home/oracle/client',
    require => Staging::File[$oracle_client_archive_name],
  }
  file { '/home/oracle/client/client_install.rsp':
    ensure  => file,
    source  => 'puppet:///modules/oracle/client_install.rsp',
    require => Staging::Extract[$oracle_client_archive_name],
  }
  file { '/home/oracle/client/install_oracle_client.sh':
    ensure  => file,
    owner   => 'root',
    group   => 'root',
    mode    => '0755',
    source  => 'puppet:///modules/oracle/install_oracle_client.sh',
    require => Staging::Extract[$oracle_client_archive_name],
  }
  exec { 'oracle_install_shell':
    command  => '/home/oracle/client/install_oracle_client.sh',
    creates  => '/u01/app/oracle/app',
    provider => shell,
    timeout  => 3600,
    require  => File['/home/oracle/client/install_oracle_client.sh'],
  }

  # 手順4. tnsnames.oraの設定
  file { '/u01/app/oracle/product/11.2.0/dbhome_1/network/admin/tnsnames.ora':
    ensure   => file,
    owner   => 'oracle',
    group   => 'oinstall',
    mode    => '0755',
    content => epp('oracle/tnsnames.ora.epp', {
       'dbname'      => 'orcl',
       'oradb'       => 'db01',
       'oraport'     => '1521',
       'servicename' => 'orcl.localdomain',
    }),
    require  => Exec['oracle_install_shell'],
  }
}
